@@ -194,8 +194,12 @@ class Adb(QObject):
                     pass
 
             res = self._do_adb_command('shell mount | grep system')
+            if '/sbin/.magisk/block/system /' in res:
+                self._syspart_name = '/sbin/.magisk/mirror/system'
             if '/system_root' in res:
                 self._syspart_name = '/system_root'
+                if '/sbin/.magisk/block/system_root /' in res:
+                    self._syspart_name = '/sbin/.magisk/mirror/system_root'
 
             # check status of selinux
             res = self._do_adb_command('shell getenforce')
@@ -424,9 +428,9 @@ class Adb(QObject):
 
         result = self._do_adb_command('shell frida --version')
         if result:
-            if 'frida: not found' in result or 'No such file or directory' in result:
+            if 'not found' in result or 'No such file or directory' in result:
                 result = self._do_adb_command('shell frida-server --version')
-                if result and 'frida-server: not found' in result:
+                if result and 'not found' in result:
                     return None
                 elif result:
                     self._alternate_frida_name = True
@@ -441,9 +445,11 @@ class Adb(QObject):
                 v_minor = int(check_ver[1])
                 v_patch = int(check_ver[2])
 
-                if v_major >= 12 and v_minor >= 5:
-                    if result:
-                        return result.join(result.split())
+                if v_major >= 12 and v_minor >= 8:
+                    return '.'.join(check_ver)
+                else:
+                    print('frida version is outdated')
+                    return '.'.join(check_ver)
             except ValueError:
                 return None
 
